@@ -1786,6 +1786,7 @@ class AnnotationTool(PanedWindow, WidgetWithMetadata):
                         message='Annotation requires that all images in the reader have the same size. Aborting.')
                     return
 
+        self.set_annotations(None)  # clear any previous existing data
         # change the tool to view
         self.image_panel.canvas.current_tool = 'VIEW'
         self.image_panel.canvas.current_tool = 'VIEW'
@@ -2678,7 +2679,7 @@ if __name__ == '__main__':
         formatter_class=argparse.RawTextHelpFormatter)
 
     parser.add_argument(
-        'input', metavar='input', default=None,
+        'input', metavar='input', default=None, nargs='?',
         help='The path to the optional image file for opening.')
     parser.add_argument(
         '-a', '--annotation', metavar='annotation', default=None,
