@@ -662,7 +662,7 @@ if __name__ == '__main__':
         formatter_class=argparse.RawTextHelpFormatter)
 
     parser.add_argument(
-        'input', metavar='input', default=None,
+        'input', metavar='input', default=None, nargs='?',
         help='The path to the optional image file for opening.')
     parser.add_argument(
         '-a', '--annotation', metavar='annotation', default=None,
